@@ -1,5 +1,5 @@
 package Games::ABC_Path::Generator::Coord;
-$Games::ABC_Path::Generator::Coord::VERSION = '0.4.2';
+$Games::ABC_Path::Generator::Coord::VERSION = '0.4.3';
 use 5.006;
 
 use strict;
@@ -34,7 +34,7 @@ Games::ABC_Path::Generator::Coord - a coordinate class.
 
 =head1 VERSION
 
-version 0.4.2
+version 0.4.3
 
 =head1 SYNOPSIS
 
@@ -44,71 +44,10 @@ B<For internal use.>.
 
 Shlomi Fish, L<http://www.shlomifish.org/> .
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-games-abc_path-generator at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-ABC_Path-Generator>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-You can find documentation for this module with the perldoc command.
-
-    perldoc Games::ABC_Path::Generator
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker (report bugs here)
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-ABC_Path-Generator>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Games-ABC_Path-Generator>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Games-ABC_Path-Generator>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Games-ABC_Path-Generator/>
-
-=back
-
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2019 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/abc-path/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
-
-=head1 SUPPORT
-
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc Games::ABC_Path::Generator::Coord
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -126,14 +65,6 @@ L<https://metacpan.org/release/Games-ABC_Path-Generator>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Games-ABC_Path-Generator>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -142,22 +73,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Games-ABC_Path-Generator>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Games-ABC_Path-Generator>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Games-ABC_Path-Generator>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -206,4 +121,25 @@ L<https://github.com/shlomif/abc-path>
 
   git clone https://github.com/shlomif/abc-path
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/abc-path/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
